##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 10: Inference About Means and Proportions with Two Populations #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################


##########################################################################
# 10.1 Inferences about the difference between two population means:     #
#      sigma1 and sigma2 known                                           #
##########################################################################

# Interval Estimation of m1 - m2
# p.485: Greystone example
# mu1 (mu2) = mean of population 1 (2) (i.e., the mean age of all customers 
# who shop at the inner-city (suburban) store)
# Inner City Store: n1 = 36, x1_bar  = 40 years, sigma1 = 9 years 
# Suburban Store: n1 = 49, x2_bar  = 35 years, sigma1 = 10 years 

n1 <- 36
x1_bar <- 40
sigma1 <- 9

n2 <- 49
x2_bar <- 35
sigma2 <- 10

alpha <- 0.05
Margin_of_error <- qnorm(1 - alpha/2) * sqrt(sigma1^2 / n1 + sigma2^2 / n2)

# 95% CI for mu1 - mu2
c((x1_bar - x2_bar) - Margin_of_error, (x1_bar - x2_bar) + Margin_of_error)



# Hypothesis Tests About m1 - m2
# p.486
# To evaluate differences in education quality between two training centers
# m1 (mu2) the mean examination score for the population 
# of individuals trained at center A (B)

library(readxl)
ExamScores <- read_excel("data/chap10/ExamScores.xlsx")
CenterA <- ExamScores$`Center A`[1:30]
CenterB <- ExamScores$`Center B`
alpha <- 0.05


par(mfrow = c(1, 2))
hist(CenterA)
hist(CenterB)


library(BSDA)
# z.test(x, y, alternative='two.sided', mu=0, sigma.x=NULL, sigma.y=NULL,conf.level=.95)
z.test.result <- z.test(CenterA, CenterB, sigma.x = 10, sigma.y = 10)
z.test.result
str(z.test.result)
z.test.result$statistic
z.test.result$p.value


##########################################################################
# 10.2 Inferences about the difference between two population means:     #
#      sigma1 and sigma2 unknown                                         #
##########################################################################

# Interval Estimation of m1 - m2

# p.490
# Clearwater National Bank would like to estimate the difference between the mean
# checking account balance maintained by the population of Cherry Grove customers and
# the population of Beechmont customers.

CheckAcct <- read_excel("data/chap10/CheckAcct.xlsx")
CherryGrove <- CheckAcct$`Cherry Grove`
Beechmont <- CheckAcct$Beechmont[1:22]

par(mfrow = c(1, 2))
hist(CherryGrove)
hist(Beechmont)


alpha <- 0.05
n1 <- length(CherryGrove)
x1_bar <- mean(CherryGrove)
s1 <- sd(CherryGrove) 
  
n2 <- length(Beechmont)
x2_bar <- mean(Beechmont)
s2 <- sd(Beechmont)

df.a <- (s1^2/n1 + s2^2/n2)^2
df.b <- (s1^2/n1)^2/(n1-1) + (s2^2/n2)^2/(n2-1)
df <- floor(df.a/df.b)

margin_of_error <- qt(1 - alpha/2, df) * sqrt(s1^2/n1 + s2^2/n2)

# 95% CI for mu1 - mu2
c((x1_bar - x2_bar) - margin_of_error,(x1_bar - x2_bar) + margin_of_error)

# or using t.test to obtain 95% CI
t.test(CherryGrove, Beechmont, alternative = "two.sided")$conf.int


# Hypothesis Tests About m1 - m2
# p.492
# m1 (m2): the mean project completion time for systems analysts
# using the current  technology (new software package)

alpha <- 0.05

SoftwareTest <- read_excel("data/chap10/SoftwareTest.xlsx")
SoftwareTest

#t.test(x, y = NULL,
#       alternative = c("two.sided", "less", "greater"),
#       mu = 0, paired = FALSE, var.equal = FALSE,
#       conf.level = 0.95)

t.test.result <- t.test(SoftwareTest$Current, SoftwareTest$New, alternative = "greater", var.equal = TRUE)
t.test.result
str(t.test.result)
t.test.result$statistic
t.test.result$p.value
t.test.result$conf.int




##########################################################################
# 10.3 Inferences about the difference between two population means:     #
#      matched samples                                                   #
##########################################################################

# p.498
# Task Completion Times for a Matched Sample Design
Matched <- read_excel("data/chap10/Matched.xlsx")
Matched
t.test(Matched$`Method 1`, Matched$`Method 2`, paired = TRUE)




##########################################################################
# 10.4 Inferences about the difference between two population proportions#
##########################################################################

# Interval Estimation of p1 - p2
# p.503: tax preparation example
# p1 (p2): proportion of erroneous returns for population 1 (population 2)

TaxPrep <- read_excel("data/chap10/TaxPrep.xlsx")
n1 <- 250
n2 <- 300
TaxPrep_Office1 <- TaxPrep$`Office 1`[1:n1]
TaxPrep_Office2 <- TaxPrep$`Office 2`[1:n2]

p1_bar <- table(TaxPrep_Office1)[2]/n1
p1_bar
p2_bar <- table(TaxPrep_Office2)[2]/n2
p2_bar

alpha <- 0.1
margin_of_error <- qnorm(1 - alpha) * sqrt(p1_bar * (1 - p1_bar) / n1 + p2_bar * (1 - p2_bar) / n2)
margin_of_error

# 90% CI for p1 - p2
round(c((p1_bar - p2_bar) - margin_of_error, (p1_bar - p2_bar) + margin_of_error), 3)



# Hypothesis Tests About p1 - p2
# prop.test(x, n, p = NULL,
#           alternative = c("two.sided", "less", "greater"),
#           conf.level = 0.95, correct = TRUE)

x <- c(table(TaxPrep_Office1)[2], table(TaxPrep_Office2)[2])
n <- c(n1, n2)
prop.test.result <- prop.test(x, n, conf.level = 0.9, correct = FALSE)
prop.test.result
str(prop.test.result)
sqrt(prop.test.result$statistic)  # z statistics = sqrt(chi-square)



