##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 15: Multiple Regression                                        #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################


##########################################################################
# 15.2 Least Squares Method                                              #
##########################################################################

# TABLE 15.2 
# Data for Butler Trucking with Miles Traveled (x1) and Number
# of Deliveries (x2) as the Independent Variables

library(readxl)
Butler <- read_excel("data/Chap15/Butler.xlsx")
print(Butler)

Butler.lm <- lm(Time ~ Kilometers + Deliveries, data = Butler)
summary(Butler.lm)



##########################################################################
# 15.3 Multiple Coefficient of Determination                             #
##########################################################################

Butler.lm.s <- summary(Butler.lm)
Butler.lm.s
Butler.lm.s$r.squared
Butler.lm.s$adj.r.squared

Butler.lm.anova <- anova(Butler.lm)
Butler.lm.anova

R2 <- sum(Butler.lm.anova$"Sum Sq"[1:2])/sum(Butler.lm.anova$"Sum Sq"[1:3])
R2
p <- 2
n <- nrow(Butler)
adjR2 <- 1-(1-R2) *(n-1)/(n-p-1)
adjR2



##########################################################################
# 5.5 Testing for Significance                                           #
##########################################################################


# FIGURE 15.6 
# Output for Butler Trucking with Two Independent Variables,
# Miles Traveled (x1) and Number of Deliveries (x2)

# F Test: H0: beta_1 = beta_2 = ... = beta_p = 0
Butler.lm.anova <- anova(Butler.lm)
Butler.lm.anova
names(Butler.lm.anova)
Butler.lm.anova$"F value"
Butler.lm.anova$"Pr(>F)" 

SSR <- sum(Butler.lm.anova$"Sum Sq"[1:2])
SSR
SSE <- Butler.lm.anova$"Sum Sq"[3]
SSE

F.value <- (SSR/p)/(SSE/(n-p-1)) 
F.value
p.value <- 1- pf(F.value, p, n-p-1)
p.value


# t Test
Butler.lm.s$coefficients

# page 750, inconsistency
# b1 = 0.06113, sb1 = 0.00989 BUT t = 0.06113/0.00989 = 6.18


# Multicollinearity
cor(Butler)
pairs(Butler)



##########################################################################
# 15.6 Using the Estimated Regression Equation for Estimation and        #
#       Prediction                                                       #
##########################################################################
new.dat <- data.frame(Kilometers = 160, Deliveries = 2)
predict(Butler.lm, newdata = new.dat, interval = "confidence")
predict(Butler.lm, newdata = new.dat, interval = "prediction")



##########################################################################
# 15.7 Categorical Independent Variables                                 #
##########################################################################


# TABLE 15.6 
# Data for the Johnson Filtration Example with Type of Repair Indicated
# by a Dummy Variable (x2 = 0 for Mechanical; x2 = 1 for Electrical)

Johnson <- read_excel("data/Chap15/Johnson2.xlsx")
print(Johnson)

colnames(Johnson) <-  c("MonthsSinceLastService",	"RepairType", "RepairTime")
print(Johnson)
str(Johnson)
Johnson$RepairType <- as.factor(Johnson$RepairType)
Johnson$RepairType <- as.factor(Johnson$RepairType, levels = c("Electrical", "Mechanical"))


# FIGURE 15.7 Output for Johnson Filtration with Months Since Last Service (x1)
# as the Independent Variable
Johnson.lm <- lm(RepairTime ~ MonthsSinceLastService + RepairType, data = Johnson)
summary(Johnson.lm)
anova(Johnson.lm)


# FIGURE 15.9 
# Scatter Diagram for the Johnson Filtration Repair Data from Table 15.6

attach(Johnson)
plot(MonthsSinceLastService, RepairTime, 
     xlab = "Months Since Last Service", 
     ylab = "Repair Time (hours)", 
     main = "Scatter Diagram for the Johnson Filtration Repair Data")
abline(a = Johnson.lm$coefficients[1], b = Johnson.lm$coefficients[2], col = "darkgreen",lwd = 2)
text(7, 3, "Repair Type = \n Mechanical", col = "darkgreen")
abline(a = sum(Johnson.lm$coefficients[c(1, 3)]), b = Johnson.lm$coefficients[2], col = "blue",lwd = 2)
text(4, 4, "Repair Type = \n Exectrical", col = "blue")



##########################################################################
# 15.8 Residual Analysis                                                 #
##########################################################################


# TABLE 15.7 
# Residuals and Standardized Residuals for the Butler Trucking Regression Analysis
Butler.std.res <- rstandard(Butler.lm)
data.frame(Predicted.value = Butler.lm$fitted.values,
           Residual = Butler.lm$residuals,
           Std.Residual = Butler.std.res)


# Figure 15.10 
# Standardized Residual Plot for Butler Trucking
plot(Butler.lm$fitted.values,  Butler.std.res, 
     main = "Standardized Residual Plot for Butler Trucking")
abline(h = 0, col = "gray", lty = 2, lwd = 2)


# TABLE 15.8 
# Studentized Deleted Residuals for Butler Trucking
data.frame(Std.Residual = Butler.std.res,
           Stud.Del.Residual = rstudent(Butler.lm))            


# TABLE 15.9 
# Leverage and Cooks Distance Measures for Butler Trucking

data.frame(Leverage = hatvalues(Butler.lm),
           Cooks.D = cooks.distance(Butler.lm))


# Influential observation: hi > 3(p+1)/n
hatvalues(Butler.lm) > 3*(ncol(Butler)-1+1)/nrow(Butler)

# Influential observation: Di > 1
cooks.distance(Butler.lm) > 1



##########################################################################
# 15.9 Logistic Regression                                               #
##########################################################################

# TABLE 15.11 
# Partial Sample Data for the Simmons Stores Example
Simmons <- read_excel("data/Chap15/Simmons.xlsx")
print(Simmons)
str(Simmons)
Simmons$Card <- as.factor(Simmons$Card)
Simmons$Coupon <- as.factor(Simmons$Coupon)


# FIGURE 15.13 
# Logistic Regression Output for the Simmons Stores Example
Simmons.glm <- glm(Coupon ~ Spending + Card, data = Simmons, family = binomial(link = "logit"))
summary(Simmons.glm)

# estimate the probability of using the coupon
# for customers who spend $2000 annually and do not/do have a Simmons credit card
predict(Simmons.glm, newdata = data.frame(Spending = 2, Card = "0"), type = "response")
predict(Simmons.glm, newdata = data.frame(Spending = 2, Card = "1"), type = "response")


# Testing for Significance: overall 
summary(Simmons.glm)
d.chi <- 134.60 - 120.97 
d.chi
d.df <- 99 - 97
d.df
1 - pchisq(d.chi, d.df)



# Testing for Significance: individuals 
anova(Simmons.glm, test = "Chisq") # FIGURE 15.13, small difference 

library(car) # Companion to Applied Regression
Anova(Simmons.glm)  # FIGURE 15.13, page. 775, the same


# A unique relationship exists between the odds ratio for a variable and 
# its corresponding regression coefficient
## odds ratios only: pages 777
coef(Simmons.glm)
exp(coef(Simmons.glm)) #odds ratios


# Note that if the CI for odds ratio includes 1, it means nonsignificance. 
# If it does not include 1, the coefficient is significant. 
# This is because for the original coefficient, 
# we compare the CI with 0. For odds ratio, exp(0) = 1.
confint(Simmons.glm)
exp(confint(Simmons.glm))     # 95% CI for exponentiated coefficients


# estimated logit = b0 + b1x1 + b2x2 + ... + bpxp
logit.0 <- predict(Simmons.glm, newdata = data.frame(Spending = 2, Card = "0"), type = "link")
logit.0
logit.1 <- predict(Simmons.glm, newdata = data.frame(Spending = 2, Card = "1"), type = "link")
logit.1


# estimated odds.0  = exp(logit.0)
exp(logit.0)
exp(logit.1)

# estimated odds ratio  = exp(logit.1)/ exp(logit.0)
exp(logit.1)/exp(logit.0)



